#!/usr/bin/env python
import argparse
from datetime import datetime
from typing import Iterable

import boto3
from botocore.config import Config


def get_ecr_pull_count(repository_name: str, start_datetime: datetime, end_datetime: datetime) -> int:
    cw_client = boto3.client("cloudwatch", config=Config(retries={"mode": "standard"}))
    response = cw_client.get_metric_statistics(
        Namespace="AWS/ECR",
        MetricName="RepositoryPullCount",
        Dimensions=[
            {"Name": "RepositoryName", "Value": repository_name},
        ],
        Statistics=["Sum"],
        StartTime=start_datetime,
        EndTime=end_datetime,
        Period=3600,  # hourly
    )
    total = 0
    for datapoint in response["Datapoints"]:
        total += datapoint["Sum"]
    return int(total)


def get_ecr_repositories() -> Iterable[str]:
    ecr_client = boto3.client("ecr", config=Config(retries={"mode": "standard"}))
    params = {}
    while True:
        res = ecr_client.describe_repositories(**params)
        for repository in res["repositories"]:
            yield repository["repositoryName"]
        if "nextToken" not in res:
            break
        params["nextToken"] = res["nextToken"]


def run(start_datetime: datetime, end_datetime: datetime):
    for repository_name in sorted(get_ecr_repositories()):
        count = get_ecr_pull_count(repository_name, start_datetime, end_datetime)
        print(f"{count},{repository_name}")


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("--start", required=True)
    parser.add_argument("--end", required=True)
    args = parser.parse_args()

    start_datetime = datetime.fromisoformat(args.start)
    end_datetime = datetime.fromisoformat(args.end)
    run(start_datetime, end_datetime)


if __name__ == "__main__":
    main()
